@@ -4,7 +4,7 @@ package XML::Atom;
 use strict;
 
 use 5.008_001;
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 BEGIN {
     @XML::Atom::EXPORT = qw( LIBXML DATETIME);
@@ -19,17 +19,6 @@ BEGIN {
     } else {
         *{XML::Atom::DATETIME} = sub() {0};
     }
-    
-    local $^W = 0;
-    *XML::XPath::Function::namespace_uri = sub {
-        my $self = shift;
-        my($node, @params) = @_;
-        my $ns = $node->getNamespace($node->getPrefix);
-        if (!$ns) {
-            $ns = ($node->getNamespaces)[0];
-        }
-        XML::XPath::Literal->new($ns ? $ns->getExpanded : '');
-    };
 
     $XML::Atom::ForceUnicode = 0;
     $XML::Atom::DefaultVersion = 0.3;
